@@ -1,5 +1,5 @@
 from django.apps import AppConfig
-from django.utils.translation import gettext_lazy as _
+from wagtailimportexport.compat import gettext_lazy as _
 
 
 class WagtailImportExportAppConfig(AppConfig):
