@@ -1,7 +1,11 @@
 from django import forms
-from django.utils.translation import gettext as _
 
-from wagtailimportexport.compat import AdminPageChooser, Page, WAGTAIL_VERSION_2_OR_GREATER
+from wagtailimportexport.compat import (
+    AdminPageChooser,
+    Page,
+    WAGTAIL_VERSION_2_OR_GREATER,
+    gettext as _,
+)
 
 
 admin_page_params = {
