@@ -1,9 +1,8 @@
 from django.conf.urls import include, url
 from django.urls import reverse
-from django.utils.translation import gettext_lazy as _
 
 from wagtailimportexport import admin_urls
-from wagtailimportexport.compat import hooks, MenuItem
+from wagtailimportexport.compat import hooks, MenuItem, gettext_lazy as _
 
 
 @hooks.register('register_admin_urls')
